Search for a specific reference using a key word or a Digital Object Identifier (DOI).
If the query is a character string, then all character columns in the table
are searched and the entries for which at least one
partial match was found are returned.
Alternatively, a named list can be used to look for an exact match in a specific column (see Details section).
Usage
search_references(query, doi = NULL, verbose = TRUE, ...)
Value
An object of class mgSearchReferences, which is a list that includes a
wide range of details associated to the reference, including all datasets
and networks related to the publication that are included in Mangal database.
Arguments
query
either a character string including a single keyword or a named list containing a custom query (see details section below).
Note that if an empty character string is passed, then all datasets available are returned.
doi
character a Digital Object Identifier (DOI) of the article. Note that query is ignored if doi is specified.
verbose
a logical. Should extra information be reported on progress?