Search network by taxon names and unique taxonomic identifiers.
This function offers the opportunity to retrieve taxon based on (i) known identifier
such as the taxonomic serial number (TSN), GBIF ID etc. or (ii) text search using partial match.
Have a look at the list of arguments to see the complete list of identifiers accessible.
If any unique identifier argument is used (i.e. tsn etc.), then query is ignored. Moreover,
if several taxonomic identifiers are specified, then only the first one is considered.
search_taxonomy(
query,
tsn = NULL,
gbif = NULL,
eol = NULL,
col = NULL,
bold = NULL,
ncbi = NULL,
verbose = TRUE,
...
)An object of class mgSearchTaxonomy, which is a data.frame including
all taxa matching the query.
a character string including a single keyword. Note that if an empty character string is passed, then all datasets available are returned.
a numeric. Unique taxonomic identifier from Integrated Taxonomic Information System (https://www.itis.gov).
a numeric. Unique taxonomic identifier from Global Biodiversity Information Facility (https://www.gbif.org).
a numeric. Unique taxonomic identifier from Encyclopedia of Life (https://eol.org).
a numeric. Unique taxonomic identifier from Catalogue of Life (https://www.catalogueoflife.org).
a numeric. Unique taxonomic identifier from Barcode of Life (http://www.boldsystems.org).
a numeric. Unique taxonomic identifier from National Center for Biotechnology Information (https://www.ncbi.nlm.nih.gov).
a logical. Should extra information be reported on progress?
further arguments to be passed to httr::GET().
Taxon names of the taxonomy table were validated with
TNRS (see https://tnrs.biendata.org and/or GNR
might not be the taxon name documented in the original publication.
In order to identify relevant networks with the original name, use
search_nodes().
The validation of taxon names was performed by an automated procedure and if there is any doubt, the original names recorded by authors should be regarded as the most reliable information. Please report any issue related to taxonomy at https://github.com/mangal-interactions/contribute/issues/new/choose/.
search_nodes()
# \donttest{
search_taxonomy("Acer")
# Retrieve higher classification
tsn_acer <- search_taxonomy("Acer")$taxonomy.tsn
# }
Run the code above in your browser using DataLab